"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.filesChanged = void 0;
var path_1 = __importDefault(require("path"));
// included here in preference to goldstack utils-sh to avoid circular dependency
var shelljs_1 = __importDefault(require("shelljs"));
var console_1 = require("console");
var isDebug = process.env.GOLDSTACK_DEBUG || process.env.DEBUG;
// included here to avoid circular dependency
// eslint-disable-next-line @typescript-eslint/no-explicit-any
var debug = function (msg) {
    if (isDebug) {
        console.log(msg);
    }
};
exports.filesChanged = function () {
    var headDiff = shelljs_1.default.exec('git diff "HEAD..HEAD^1" --quiet -- . ');
    var headChanged = headDiff.code !== 0;
    if (headChanged) {
        debug('Detected change against HEAD^1 in ' + path_1.default.resolve('.'));
    }
    var fileDiff = shelljs_1.default.exec('git diff --quiet -- . ');
    var fileChanged = fileDiff.code !== 0;
    if (fileChanged) {
        debug('Detected uncommited change in ' + path_1.default.resolve('.'));
    }
    if (headChanged || fileChanged) {
        return true;
    }
    else {
        return false;
    }
};
exports.run = function (args) {
    console_1.assert(args[3] === '--exec');
    var execCommands = args.slice(4);
    var execCommand = execCommands.join(' ');
    if (args[2] === 'changed') {
        if (exports.filesChanged()) {
            var res = shelljs_1.default.exec(execCommand);
            if (res.code !== 0) {
                console.log(res.stdout);
                console.log(res.stderr);
                console.log('Error when running "' + execCommand + '"');
                process.exit(res.code);
            }
            else {
                console.log(res.stdout);
            }
        }
        else {
            console.log('No file changes detected in ' + path_1.default.resolve('.'));
        }
    }
    else {
        console.log('Please provide argument changed.');
        process.exit(1);
    }
};
//# sourceMappingURL=utilsGit.js.map